@@ -15,6 +15,54 @@ from ctypes import *
 from enum import Enum
 
 
+class RhinoError(Exception):
+    pass
+
+
+class RhinoMemoryError(RhinoError):
+    pass
+
+
+class RhinoIOError(RhinoError):
+    pass
+
+
+class RhinoInvalidArgumentError(RhinoError):
+    pass
+
+
+class RhinoStopIterationError(RhinoError):
+    pass
+
+
+class RhinoKeyError(RhinoError):
+    pass
+
+
+class RhinoInvalidStateError(RhinoError):
+    pass
+
+
+class RhinoRuntimeError(RhinoError):
+    pass
+
+
+class RhinoActivationError(RhinoError):
+    pass
+
+
+class RhinoActivationLimitError(RhinoError):
+    pass
+
+
+class RhinoActivationThrottledError(RhinoError):
+    pass
+
+
+class RhinoActivationRefusedError(RhinoError):
+    pass
+
+
 class Rhino(object):
     """
     Python binding for Rhino Speech-to-Intent engine. It directly infers the user's intent from spoken commands in
@@ -40,19 +88,28 @@ class Rhino(object):
         ACTIVATION_REFUSED = 11
 
     _PICOVOICE_STATUS_TO_EXCEPTION = {
-        PicovoiceStatuses.OUT_OF_MEMORY: MemoryError,
-        PicovoiceStatuses.IO_ERROR: IOError,
-        PicovoiceStatuses.INVALID_ARGUMENT: ValueError,
-        PicovoiceStatuses.STOP_ITERATION: StopIteration,
-        PicovoiceStatuses.KEY_ERROR: KeyError,
-        PicovoiceStatuses.INVALID_STATE: ValueError,
-        PicovoiceStatuses.RUNTIME_ERROR: RuntimeError,
-        PicovoiceStatuses.ACTIVATION_ERROR: RuntimeError,
-        PicovoiceStatuses.ACTIVATION_LIMIT_REACHED: PermissionError,
-        PicovoiceStatuses.ACTIVATION_THROTTLED: PermissionError,
-        PicovoiceStatuses.ACTIVATION_REFUSED: PermissionError
+        PicovoiceStatuses.OUT_OF_MEMORY: RhinoMemoryError,
+        PicovoiceStatuses.IO_ERROR: RhinoIOError,
+        PicovoiceStatuses.INVALID_ARGUMENT: RhinoInvalidArgumentError,
+        PicovoiceStatuses.STOP_ITERATION: RhinoStopIterationError,
+        PicovoiceStatuses.KEY_ERROR: RhinoKeyError,
+        PicovoiceStatuses.INVALID_STATE: RhinoInvalidStateError,
+        PicovoiceStatuses.RUNTIME_ERROR: RhinoRuntimeError,
+        PicovoiceStatuses.ACTIVATION_ERROR: RhinoActivationError,
+        PicovoiceStatuses.ACTIVATION_LIMIT_REACHED: RhinoActivationLimitError,
+        PicovoiceStatuses.ACTIVATION_THROTTLED: RhinoActivationThrottledError,
+        PicovoiceStatuses.ACTIVATION_REFUSED: RhinoActivationRefusedError
     }
 
+    Inference = namedtuple('Inference', ['is_understood', 'intent', 'slots'])
+    Inference.__doc__ = """"\
+    Immutable object with `.is_understood`, `.intent` , and `.slots` getters.
+    
+    :param is_understood: Indicates whether the intent was understood by Rhino.
+    :param intent: Name of intent that was inferred
+    :param slots: Dictionary of the slot keys and values extracted from the utterance.
+    """
+
     class CRhino(Structure):
         pass
 
@@ -185,14 +242,12 @@ class Rhino(object):
 
         return is_finalized.value
 
-    Inference = namedtuple('Inference', ['is_understood', 'intent', 'slots'])
-
     def get_inference(self):
         """
          Gets inference results from Rhino. If the spoken command was understood, it includes the specific intent name
          that was inferred, and (if applicable) slot keys and specific slot values. Should only be called after the
          process function returns true, otherwise Rhino has not yet reached an inference conclusion.
-         :return An immutable object with `.is_understood`, '.intent` , and `.slots` getters.
+         :return Inference object with `.is_understood`, `.intent` , and `.slots` getters.
         """
 
         is_understood = c_bool()
